@@ -4,8 +4,11 @@ Created By Murray(m18527) on 2019/9/9 11:34
 """
 
 from .utils.core import config
-from .client.action import DataClient
+from .client.action import DataClient, DataClientV1, DataClientV2, DataClientV3
 
 __all__ = [
     'DataClient',
+    'DataClientV1',
+    'DataClientV2',
+    'DataClientV3'
 ]
