@@ -77,13 +77,10 @@ class DataClient(object):
 
         code_list, msg_list = [], []
         for index, t in enumerate(teachers):
-            teacher_sso_data = t.sso_data
             if t.uid:
-                teacher_sso_data.pop("password")
-                code, rlt = update_teacher_req(t.uid, teacher_sso_data, school_id=t.school)
+                code, rlt = update_teacher_req(t.uid, t.sso_data, school_id=t.school)
             elif t.number in teacher_map:
-                teacher_sso_data.pop("password")
-                code, rlt = update_teacher_req(teacher_map[t.number], teacher_sso_data, school_id=t.school)
+                code, rlt = update_teacher_req(teacher_map[t.number], t.sso_data, school_id=t.school)
             else:
                 code, rlt = create_teacher_req(t.sso_data, school_id=t.school)
             if code:
@@ -542,19 +539,6 @@ class DataClient(object):
         backbone.delete_subject(uid)
         return
 
-    @staticmethod
-    def upload_user_avatar(school_id, file_path, user_id):
-        backbone = Backbone(school_id)
-        return backbone.upload_user_avatar(file_path, user_id)
-
-    @staticmethod
-    def upload_user_face(school_id, file_path, student_id=None, teacher_id=None):
-        if not (student_id or teacher_id):
-            return None
-        data = {"student_id": student_id} if student_id else {"teacher_id": teacher_id}
-        backbone = Backbone(school_id)
-        return backbone.upload_user_face(file_path, data)
-
 
 class DataClientV1(DataClient):
     @staticmethod
@@ -693,10 +677,6 @@ class DataClientV3(DataClient):
         return data
 
     def delete_student(self, params, school_id):
-        student_id = params.get("student_id", None)
-        if student_id:
-            code, data = delete_student_req(student_id, school_id)
-            return code, data
         data = self.get_student_info(params, school_id)
         if len(data) > 1:
             return ERROR_PARAMS, "查询学生信息不唯一"
