@@ -656,12 +656,6 @@ class Backbone(object):
                     room_list.extend(room)
         return room_list
 
-    def upload_user_avatar(self, file_path, user_id):
-        return self.edtech_requester.upload_user_avatar(file_path, user_id)
-
-    def upload_user_face(self, file_path, data):
-        return self.nirvana_requester.upload_face_file(file_path, data)
-
     def upload_meeting_rooms(self, meeting_rooms):
         self.wrap_student_map()
         self.wrap_teacher_map()
