@@ -15,16 +15,15 @@ class TypeSet(object):
 
 
 class News(BaseModel):
-    uid = None
-    title = None  # 必填*
-    content = None  # 必填*
-    description = None
-    category = TypeSet.SCHOOL_TYPE
-    school = None
-    class_name = None
-    classroom_numbers = []
-
     def __init__(self, *args, **kwargs):
+        self.uid = None
+        self.title = None  # 必填*
+        self.content = None  # 必填*
+        self.description = None
+        self.category = TypeSet.SCHOOL_TYPE
+        self.school = None
+        self.class_name = None
+        self.classroom_numbers = []
         super(News, self).__init__(*args, **kwargs)
         self.required_filed = ['title', 'content']
         self.class_id = None
