@@ -305,10 +305,3 @@ class NirvanaRequester(Requester):
                 "force": True}
         res = self._delete_method(route, data)
         return res
-
-    def upload_face_file(self, file_path, data):
-        route = "/api/upload_face_img/"
-        data["category"] = "face"
-        with open(file_path, 'rb') as f:
-            res = self._post_file_method(route, {'file': f}, data=data)
-        return res
